@@ -10,6 +10,12 @@ class ForecastConfig:
     freq: str = 'Y'
     prophet_kwargs:  dict = field(default_factory=lambda: {})
 
+    def __post_init__(self):
+        if self.freq.casefold() == 'y':
+            self.freq = '12m'
+        elif self.freq.casefold() == 'q':
+            self.freq = '3m'
+
     @property
     def make_future_df_kwargs(self) -> Dict[str, Union[int, str]]:
         return dict(
